#ifarch noarch
%if 0%{?fedora} > 8
# set this to 0 to disable -apidocs for a faster build
%define apidocs 1
%else
# don't build apidocs on Fedora < 9 for now, because we don't have the required
# files from KDE 4 in %{_kde4_docdir}/HTML/en/common due to conflicts with KDE 3
%define apidocs 0
%endif
#else
%define rest 1
#endif

%if 0
#if 0%{?fedora} > 9
# Use system libical (requires libical-devel >= 0.33)
# Disabled for now because of #469228
%define with_libical 1
%endif

Name: kdepimlibs

Version: 4.1.2
Release: 4%{?dist}
Summary: K Desktop Environment 4 - PIM Libraries

License: LGPLv2
Group: System Environment/Libraries

URL: http://www.kde.org/
Source0: ftp://ftp.kde.org/pub/kde/unstable/%{version}/src/kdepimlibs-%{version}.tar.bz2
# Use system libical (will be in 4.2)
Patch100:      kdepimlibs-4.1.2-system-libical.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

Requires: kdelibs4 >= %{version}

BuildRequires: akonadi-devel
BuildRequires: boost-devel
BuildRequires: cmake
BuildRequires: cyrus-sasl-devel
BuildRequires: gpgme-devel
BuildRequires: kdelibs4-devel >= %{version}
BuildRequires: libXpm-devel libXtst-devel
BuildRequires: openldap-devel
%if 0%{?with_libical}
BuildRequires: libical-devel >= 0.33
%endif
%{?_kde4_macros_api:Requires: kde4-macros(api) = %{_kde4_macros_api} }

# work around circular dependency from kdelibs4-devel 
# pulling in phonon-backend-xine
#BuildRequires: phonon-backend-gstreamer

## upstream patches

%if 0%{?apidocs}
BuildRequires: doxygen
BuildRequires: graphviz
BuildRequires: qt4-doc
%endif

%description
Personal Information Management (PIM) libraries for the
K Desktop Environment 4.

%package devel
Group:    Development/Libraries
Summary:  Development files for %{name} 
Requires: %{name} = %{version}-%{release}
Obsoletes: kdepimlibs4-devel < %{version}-%{release}
Provides:  kdepimlibs4-devel = %{version}-%{release}
Requires: kdelibs4-devel
Requires: boost-devel

%description devel
Header files for developing applications using %{name}.

%package apidocs
Group: Development/Documentation
Summary: kdepimlibs API documentation
Requires: kde-filesystem

%description apidocs
This package includes the kdepimlibs API documentation in HTML
format for easy browsing.


%prep
%setup -q -n kdepimlibs-%{version}
%if 0%{?with_libical}
# use system libical
%patch100 -p1
rm -rf kcal/libical
%endif


%build

mkdir -p %{_target_platform}
pushd %{_target_platform}
%{cmake_kde4} ..
popd

%if 0%{?rest}
make %{?_smp_mflags} -C %{_target_platform} VERBOSE=1
%endif

# build apidocs
%if 0%{?apidocs}
export QTDOCDIR=`pkg-config --variable=docdir Qt`
kde4-doxygen.sh --doxdatadir=%{_kde4_docdir}/HTML/en/common .
%endif


%install
rm -rf %{buildroot}

%if 0%{?rest}
make install DESTDIR=%{buildroot} -C %{_target_platform}

# move devel symlinks
mkdir -p %{buildroot}%{_kde4_libdir}/kde4/devel
pushd %{buildroot}%{_kde4_libdir}
for i in lib*.so
do
  case "$i" in
    libkdeinit4_*.so)
      ;;
    *)
      linktarget=`readlink "$i"`
      rm -f "$i"
      ln -sf "../../$linktarget" "kde4/devel/$i"
      ;;
  esac
done
popd
%endif

# install apidocs
%if 0%{?apidocs}
mkdir -p %{buildroot}%{_kde4_docdir}/HTML/en
cp -prf kdepimlibs-%{version}-apidocs %{buildroot}%{_kde4_docdir}/HTML/en/kdepimlibs-apidocs
%endif


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%clean
rm -rf %{buildroot} 


%if 0%{?rest}
%files
%defattr(-,root,root,-)
%{_kde4_appsdir}/akonadi-kde/
%{_kde4_appsdir}/kabc/
%if !0%{?with_libical}
%{_kde4_appsdir}/libical/
%endif
%{_kde4_appsdir}/kconf_update/*
%{_kde4_datadir}/config.kcfg/*
%{_datadir}/dbus-1/interfaces/*
%{_kde4_datadir}/kde4/services/*
%{_kde4_datadir}/kde4/servicetypes/*
%{_kde4_libdir}/lib*.so.*
%{_kde4_libdir}/kde4/*
%{_kde4_libdir}/gpgmepp/
%exclude %{_kde4_libdir}/kde4/devel/

%files devel
%defattr(-,root,root,-)
%{_kde4_appsdir}/cmake/modules/*
%{_kde4_includedir}/*
%{_kde4_libdir}/kde4/devel/lib*.so
%endif

%if 0%{?apidocs}
%files apidocs
%defattr(-,root,root,-)
%{_kde4_docdir}/HTML/en/kdepimlibs-apidocs/
%endif


%changelog
* Sat Nov 01 2008 Kevin Kofler <Kevin@tigcc.ticalc.org> 4.1.2-4
- turn off system libical for now, crashes KOrganizer (#469228)

* Tue Oct 28 2008 Kevin Kofler <Kevin@tigcc.ticalc.org> 4.1.2-3
- build against the system libical (F10+ only for now)

* Sun Sep 28 2008 Rex Dieter <rdieter@fedoraproject.org> 4.1.2-2
- make VERBOSE=1
- respin against new(er) kde-filesystem

* Fri Sep 26 2008 Rex Dieter <rdieter@fedoraproject.org> 4.1.2-1
- 4.1.2

* Fri Sep 05 2008 Rex Dieter <rdieter@fedoraproject.org> 4.1.1-2
- invitations crasher/regression (kde #170203, rh#462103)

* Thu Aug 28 2008 Than Ngo <than@redhat.com> 4.1.1-1
- 4.1.1

* Tue Aug 05 2008 Rex Dieter <rdieter@fedoraproject.org> 4.1.0-2
- -devel: Requires: boost-devel

* Wed Jul 23 2008 Than Ngo <than@redhat.com> 4.1.0-1
- 4.1.0

* Fri Jul 18 2008 Rex Dieter <rdieter@fedoraproject.org> 4.0.99-1
- 4.0.99

* Thu Jul 10 2008 Rex Dieter <rdieter@fedoraproject.org> 4.0.98-1
- 4.0.98

* Sun Jul 06 2008 Rex Dieter <rdieter@fedoraproject.org> 4.0.85-1
- 4.0.85

* Fri Jun 27 2008 Rex Dieter <rdieter@fedoraproject.org> 4.0.84-1
- 4.0.84

* Tue Jun 24 2008 Than Ngo <than@redhat.com> 4.0.83-2
- respun

* Thu Jun 19 2008 Than Ngo <than@redhat.com> 4.0.83-1
- 4.0.83 (beta2)

* Sat Jun 14 2008 Rex Dieter <rdieter@fedoraproject.org> 4.0.82-1
- 4.0.82

* Mon May 26 2008 Than Ngo <than@redhat.com> 4.0.80-1
- 4.1 beta1

* Mon May 05 2008 Kevin Kofler <Kevin@tigcc.ticalc.org> - 4.0.72-2
- add BR akonadi-devel
- update file list

* Fri May 02 2008 Kevin Kofler <Kevin@tigcc.ticalc.org> - 4.0.72-1
- update to 4.0.72 (4.1 alpha 1)

* Thu Apr 03 2008 Kevin Kofler <Kevin@tigcc.ticalc.org> 4.0.3-3
- rebuild (again) for the fixed %%{_kde4_buildtype}

* Mon Mar 31 2008 Kevin Kofler <Kevin@tigcc.ticalc.org> 4.0.3-2
- rebuild for NDEBUG and _kde4_libexecdir

* Fri Mar 28 2008 Than Ngo <than@redhat.com> 4.0.3-1
- 4.0.3
- -apidocs: Drop Requires: %%name
- include noarch build hooks (not enabled)

* Thu Mar 06 2008 Kevin Kofler <Kevin@tigcc.ticalc.org> 4.0.2-2
- build apidocs and put them into an -apidocs subpackage (can be turned off)
- BR doxygen, graphviz and qt4-doc when building apidocs

* Thu Feb 28 2008 Than Ngo <than@redhat.com> 4.0.2-1
- 4.0.2

* Wed Jan 30 2008 Kevin Kofler <Kevin@tigcc.ticalc.org> 4.0.1-2
- don't delete kconf_update script, it has been fixed to do the right thing

* Wed Jan 30 2008 Rex Dieter <rdieter@fedoraproject.org> 4.0.1-1
- 4.0.1

* Mon Jan 07 2008 Than Ngo <than@redhat.com> 4.0.0-1
- 4.0.0

* Tue Dec 11 2007 Kevin Kofler <Kevin@tigcc.ticalc.org> 3.97.0-2
- rebuild for changed _kde4_includedir

* Wed Dec 05 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.97.0-1
- kde-3.97.0

* Thu Nov 29 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.96.2-1
- kde-3.96.2

* Tue Nov 27 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.96.1-2
- kde-3.96.1

* Thu Nov 15 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.96.0-1
- kde-3.96.0

* Fri Nov 09 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.95.2-1
- kde-3.95.2

* Mon Nov 05 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.95.0-1
- kde-3.95.0 (kde4 dev platform rc1)

* Thu Oct 18 2007 Kevin Kofler <Kevin@tigcc.ticalc.org> 3.94.0-1
- update to 3.94.0
- add new %%{_kde4_libdir}/Gpgmepp directory to file list

* Thu Oct 4 2007 Kevin Kofler <Kevin@tigcc.ticalc.org> 3.93.0-4
- drop ExcludeArch: ppc64 (#300591)

* Fri Sep 21 2007 Kevin Kofler <Kevin@tigcc.ticalc.org> 3.93.0-3
- ExcludeArch: ppc64 (#300591)

* Thu Sep 13 2007 Kevin Kofler <Kevin@tigcc.ticalc.org> 3.93.0-2
- delete KMail/KNode transport migration scripts which break KDE 3

* Sun Sep 9 2007 Kevin Kofler <Kevin@tigcc.ticalc.org> 3.93.0-1
- update to 3.93.0
- drop kde4home patch (no longer applied)
- list BR strigi-devel only once
- move devel symlinks to %%{_kde4_libdir}/kde4/devel/

* Tue Aug 14 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.92.0-4
- use macros.kde4
- License: LGPLv2

* Mon Jul 30 2007 Than Ngo <than@redhat.com> 3.92.0-2
- add BR: gpgme-devel

* Sat Jul 28 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.92.0-1
- kde-3.92 (kde-4-beta1)

* Thu Jun 29 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.91.0-3
- fix %%_sysconfdir for %%_prefix != /usr case.

* Thu Jun 28 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.91.0-2
- updated kde4home.diff
- CMAKE_BUILD_TYPE=RelWithDebInfo (we're already using %%optflags)
- drop SNPRINTF hack

* Wed Jun 27 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.91.0-1
- kde-3.91.0
- CMAKE_BUILD_TYPE=debug

* Sat Jun 23 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.90.1-2
- specfile cleanup (%%prefix issues mostly)

* Sun May 13 2007 Kevin Kofler <Kevin@tigcc.ticalc.org> 3.90.1-1
- update to 3.90.1
- bump cmake BR to 2.4.5 as required upstream now
- don't set execute bits by hand anymore, cmake has been fixed
- use multilibs in /opt/kde4
- add BR boost-devel

* Fri Mar 23 2007 Kevin Kofler <Kevin@tigcc.ticalc.org> 3.80.3-4
- restore minimum version requirement for cmake
- don't set QT4DIR and PATH anymore, qdbuscpp2xml has been fixed

* Mon Mar 05 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.80.3-3
- +eXecute perms for %%{prefix}/lib/*

* Fri Feb 23 2007 Kevin Kofler <Kevin@tigcc.ticalc.org> 3.80.3-2
- rebuild for patched FindKDE4Internal.cmake

* Wed Feb 21 2007 Kevin Kofler <Kevin@tigcc.ticalc.org> 3.80.3-1
- update to 3.80.3
- update and improve parallel-installability patch
- readd BR cyrus-sasl-devel
- don't set LD_LIBRARY_PATH
- set QT4DIR and PATH so CMake's direct $QT4DIR/qdbuscpp2xml calls work
- define HAVE_SNPRINTF to work around vsnprintf.c build failure

* Wed Nov 29 2006 Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> 3.80.2-0.3.20061003svn
- dropped -DCMAKE_SKIP_RPATH=TRUE from cmake
- compiling with QA_RPATHS=0x0003; export QA_RPATHS
- added libXtst-devel libXpm-devel as BR
	
* Fri Nov 24 2006 Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> 3.80.2-0.2.20061003svn
- parallel build support
- added -DCMAKE_SKIP_RPATH=TRUE to cmake to skip rpath
- dropped qt4-devel >= 4.2.0, cyrus-sasl-devel  as BR
- spec file cleanups and added clean up in %%install
- fixed PATH for libkdecore.so.5; cannot open shared object file;

* Sat Oct 07 2006 Kevin Kofler <Kevin@tigcc.ticalc.org> 3.80.2-0.1.20061003svn
- first Fedora RPM (parts borrowed from the OpenSUSE kdepimlibs 4 RPM and the Fedora kdelibs 3 RPM)
- apply parallel-installability patch
